@@ -6,9 +6,9 @@ import edalize.edatool
 
 
 def test_vunit_codegen(make_edalize_test):
-    tf = make_edalize_test('vunit', param_types=['cmdlinearg'])
+    tf = make_edalize_test("vunit", param_types=["cmdlinearg"])
     tf.backend.configure()
-    tf.compare_files(['run.py'])
+    tf.compare_files(["run.py"])
 
 
 def test_vunit_hooks(tmpdir):
@@ -20,31 +20,36 @@ def test_vunit_hooks(tmpdir):
     from unittest import mock
     from edalize import get_edatool
 
-    sys.path = [os.path.join(tests_dir, __name__, 'vunit_mock')] + sys.path
+    sys.path = [os.path.join(tests_dir, __name__, "vunit_mock")] + sys.path
 
-    ref_dir = os.path.join(tests_dir, __name__, 'minimal')
-    tool = 'vunit'
-    name = 'test_' + tool + '_minimal_0'
+    ref_dir = os.path.join(tests_dir, __name__, "minimal")
+    tool = "vunit"
+    name = "test_" + tool + "_minimal_0"
     work_root = str(tmpdir)
 
-    files = [{'name' : os.path.join(ref_dir, 'vunit_runner_test.py'),
-              'file_type' : 'pythonSource-3.7'},
-             {'name' : os.path.join(ref_dir, 'tb_minimal.vhd'),
-              'file_type' : 'vhdlSource-2008',
-              'logical_name' : 'libx'}]
+    files = [
+        {
+            "name": os.path.join(ref_dir, "vunit_runner_test.py"),
+            "file_type": "pythonSource-3.7",
+        },
+        {
+            "name": os.path.join(ref_dir, "tb_minimal.vhd"),
+            "file_type": "vhdlSource-2008",
+            "logical_name": "libx",
+        },
+    ]
 
-    edam = {'name'     : name,
-            'files'    : files,
-            'toplevel' : 'top'}
+    edam = {"name": name, "files": files, "toplevel": "top"}
 
     backend = get_edatool(tool)(edam=edam, work_root=work_root)
 
     original_impl = edalize.edatool.run
 
     def subprocess_intercept(args, **kwargs):
-        if len(args) > 1 and args[1].endswith('run.py'):
+        if len(args) > 1 and args[1].endswith("run.py"):
             import sys
-            with patch.object(sys, 'argv', args):
+
+            with patch.object(sys, "argv", args):
                 spec = importlib.util.spec_from_file_location("__main__", args[1])
                 runner_script = importlib.util.module_from_spec(spec)
 
@@ -53,10 +58,10 @@ def test_vunit_hooks(tmpdir):
         else:
             return original_impl(args, **kwargs)
 
-    with mock.patch('edalize.edatool.run', new=subprocess_intercept):
+    with mock.patch("edalize.edatool.run", new=subprocess_intercept):
         backend.configure()
 
-        with mock.patch('edalize.vunit_hooks.VUnitRunner') as hooks_constructor:
+        with mock.patch("edalize.vunit_hooks.VUnitRunner") as hooks_constructor:
             hooks = MagicMock()
             vu_library = MagicMock()
             vu_mock = MagicMock()
@@ -71,10 +76,10 @@ def test_vunit_hooks(tmpdir):
 
             vu_mock.add_library.assert_called_with("libx")
             hooks.create.assert_called_once_with()
-            hooks.handle_library.assert_called_with('libx', vu_library)
+            hooks.handle_library.assert_called_with("libx", vu_library)
             hooks.main.assert_called_with(vu_mock)
 
-        with mock.patch('edalize.vunit_hooks.VUnitRunner') as hooks_constructor:
+        with mock.patch("edalize.vunit_hooks.VUnitRunner") as hooks_constructor:
             hooks = MagicMock()
             vu_library = MagicMock()
             vu_mock = MagicMock()
@@ -88,12 +93,13 @@ def test_vunit_hooks(tmpdir):
             hooks.create.assert_called_once_with()
             vu_mock.add_library.assert_called_with("libx")
             hooks.create.assert_called_once_with()
-            hooks.handle_library.assert_called_with('libx', vu_library)
+            hooks.handle_library.assert_called_with("libx", vu_library)
             hooks.main.assert_called_with(vu_mock)
 
 
-if __name__ == '__main__':
+if __name__ == "__main__":
     from os.path import dirname
     import sys
+
     sys.path.append(dirname(dirname(__file__)))
     pytest.main(args=[__file__])
